This is the user guide for odin-control. See [Getting Started] for an introductory tutorial. Further
details are given the pages listed below.

- [Installation](installation.md)
- [Configuration](configuration.md)
- [Key Concepts](key-concepts.md)

[Getting Started]: ../getting-started.md
